==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QClipBlendValue.java <==
package io.qt.qt3d.animation;


/**
 * <p>Class used for including a clip in a blend tree</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qclipblendvalue.html">Qt3DAnimation::QClipBlendValue</a></p>
 */
public class QClipBlendValue extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QClipBlendValue.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::clipChanged(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clip")
    public final Signal1<io.qt.qt3d.animation.QAbstractAnimationClip> clipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip, io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip clip) {
        this(clip, (io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip clip, io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, clip, parent);
    }
    
    private native static void initialize_native(QClipBlendValue instance, io.qt.qt3d.animation.QAbstractAnimationClip clip, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Overloaded constructor for {@link #QClipBlendValue(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipBlendValue() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipBlendValue(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QClipBlendValue instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::clip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractAnimationClip clip(){
        return clip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractAnimationClip clip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::setClip(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clip")
    public final void setClip(io.qt.qt3d.animation.QAbstractAnimationClip clip){
        setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clip));
    }
    
    private native void setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(long __this__nativeId, long clip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QClipBlendValue(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QClipBlendValue(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QClipBlendValue instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.3.0-sources.jar: io/qt/qt3d/animation/QClipBlendValue.java <==
package io.qt.qt3d.animation;


/**
 * <p>Class used for including a clip in a blend tree</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qclipblendvalue.html">Qt3DAnimation::QClipBlendValue</a></p>
 */
public class QClipBlendValue extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QClipBlendValue.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::clipChanged(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clip")
    public final Signal1<io.qt.qt3d.animation.QAbstractAnimationClip> clipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip, io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip clip) {
        this(clip, (io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipBlendValue(io.qt.qt3d.animation.QAbstractAnimationClip clip, io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, clip, parent);
    }
    
    private native static void initialize_native(QClipBlendValue instance, io.qt.qt3d.animation.QAbstractAnimationClip clip, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Overloaded constructor for {@link #QClipBlendValue(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipBlendValue() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipBlendValue(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QClipBlendValue instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::clip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractAnimationClip clip(){
        return clip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractAnimationClip clip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipblendvalue.html#clip-prop">Qt3DAnimation::QClipBlendValue::setClip(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clip")
    public final void setClip(io.qt.qt3d.animation.QAbstractAnimationClip clip){
        setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clip));
    }
    
    private native void setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(long __this__nativeId, long clip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QClipBlendValue(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QClipBlendValue(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QClipBlendValue instance, QDeclarativeConstructor constructor);
    
}
